import os
import json
import shutil

def convert_spruce_leaf_models(source_dir):
    if not os.path.exists(source_dir):
        print(f"Source directory {source_dir} does not exist.")
        return

    leaf_types = ['birch', 'oak', 'jungle', 'acacia', 'dark_oak', 'mangrove', 'cherry', 'pale_oak', 'azalea', 'flowering_azalea']

    for filename in os.listdir(source_dir):
        if not filename.startswith('spruce_') or not filename.endswith('.json'):
            continue

        source_path = os.path.join(source_dir, filename)

        with open(source_path, 'r') as f:
            model_data = json.load(f)

        for target_leaf in leaf_types:
            new_model_data = json.loads(json.dumps(model_data))

            for section in new_model_data.get('textures', {}):
                if 'all' in new_model_data['textures']:
                    new_model_data['textures']['all'] = new_model_data['textures']['all'].replace(
                            'block/spruce_leaves', 
                            f'block/{target_leaf}_leaves'
                            )
                if 'particle' in new_model_data['textures']:
                    new_model_data['textures']['particle'] = new_model_data['textures']['particle'].replace(
                            'block/leaves_wires_1', 
                            f'block/leaves_wires_1'
                            )

            new_filename = filename.replace('spruce_', f'{target_leaf}_')
            new_path = os.path.join(source_dir, new_filename)

            with open(new_path, 'w') as f:
                json.dump(new_model_data, f, indent='\t')

            print(f"Created: {new_filename}")

if __name__ == "__main__":
    source_directory = '.'

    convert_spruce_leaf_models(source_directory)
